from machine import Pin, I2C
from ssd1306 import SSD1306_I2C
import time as time
import utime

i2c=I2C(0,sda=Pin(0), scl=Pin(1), freq=400000)
oled = SSD1306_I2C(128, 64, i2c)

ledPin1 = Pin(16, Pin.OUT)
ledPin2 = Pin(17, Pin.OUT)
ledPin3 = Pin(18, Pin.OUT)
ledPin4 = Pin(20, Pin.OUT)

sensor1Trigger = Pin(2, Pin.OUT)
sensor1Echo = Pin(3, Pin.IN)
sensor2Trigger = Pin(4, Pin.OUT)
sensor2Echo = Pin(5, Pin.IN)
sensor3Trigger = Pin(6, Pin.OUT)
sensor3Echo = Pin(7, Pin.IN)
sensor4Trigger = Pin(8, Pin.OUT)
sensor4Echo = Pin(9, Pin.IN)

sensor1Value = 12
sensor2Value = 12
sensor3Value = 12
sensor4Value = 12

sensorActiveDistance = 10

def setup():
    ledPin1.off()
    ledPin2.off()
    ledPin3.off()
    ledPin4.off()

def toggleLED(pin):
  pin.toggle()

def formatValue(value):
    return str("{:4.2f}".format(value)+" cm")

def updateDisplay():
    global sensor1Value, sensor2Value, sensor3Value, sensor4Value
    
    oled.fill(0)
    oled.text("#1 "+formatValue(sensor1Value), 0, 0)
    oled.text("#2 "+formatValue(sensor2Value), 0, 15)
    oled.text("#3 "+formatValue(sensor3Value), 0, 30)
    oled.text("#4 "+formatValue(sensor4Value), 0, 45)    
    oled.show()    

def readUltrasonicSensor(trigger, echo):
    trigger.low()
    utime.sleep_us(2)
    trigger.high()
    utime.sleep_us(5)
    trigger.low()
    
    signaloff = 0
    while echo.value() == 0:
        signaloff = utime.ticks_us()
    
    signalon = 0
    while echo.value() == 1:
        signalon = utime.ticks_us()
        
    timepassed = signalon - signaloff
    
    return (timepassed * 0.0343) / 2

def checkValueSetState(value, pin):
    if (value < sensorActiveDistance):
        pin.on()
    else:
        pin.off()
        
def main():
    global sensor1Value, sensor2Value, sensor3Value, sensor4Value
    while True:
        sensor1Value = readUltrasonicSensor(sensor1Trigger, sensor1Echo)
        sensor2Value = readUltrasonicSensor(sensor2Trigger, sensor2Echo)
        sensor3Value = readUltrasonicSensor(sensor3Trigger, sensor3Echo)
        sensor4Value = readUltrasonicSensor(sensor4Trigger, sensor4Echo)
        checkValueSetState(sensor1Value, ledPin1)
        checkValueSetState(sensor2Value, ledPin2)
        checkValueSetState(sensor3Value, ledPin3)
        checkValueSetState(sensor4Value, ledPin4)    
        updateDisplay()
        time.sleep(0.5)

setup()
main()  
